#
# spec file for package perl-Sub-Quote
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Sub-Quote
Name:           perl-Sub-Quote
Version:        2.006008
Release:        1.5
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Efficient generation of subroutines via string eval
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/H/HA/HAARG/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Test::More) >= 0.94
Recommends:     perl(Sub::Util)
%{perl_requires}

%description
This package provides performant ways to generate subroutines from strings.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license LICENSE

%changelog
* Sat Jan 21 2023 Tina Müller <timueller+perl@suse.de>
- updated to 2.006008
  see /usr/share/doc/packages/perl-Sub-Quote/Changes
  2.006008 - 2023-01-20
  - drop Test::Fatal prereq
  - recommend Sub::Util rather than Sub::Name
  - use XString for quoting strings where possible
  - move tests for quotify on perl 5.6 to author only
  2.006_007 - 2022-04-05
  - accurately detect numbers vs strings in quotify on perl 5.36
  - accurately detect booleans in quotify on perl 5.36
  - add workaround for float formatting for perls compiled to use gcvd
* Fri Oct  4 2019 <timueller+perl@suse.de>
- updated to 2.006006
  see /usr/share/doc/packages/perl-Sub-Quote/Changes
  2.006006 - 2019-10-01
  - change quotify to use longest form of floating point numbers if unable to
    find a perfectly accurate representation
  - updated documentation for quotify to reflect handling of floating point
    numbers
  - don't try to copy hints hash entries that look like references (RT#122698)
  2.006_005 - 2019-09-06
  - additional fixes for quotify for floating point numbers to be faster and
    should always be able to maintain accuracy
  2.006_004 - 2019-04-24
  - change quotify of NaNs to simpler calculation
  - avoid ever triggering exceptions when testing for quotify on false values
  - skip quotify Inf and NaN tests if perl is compiled without support for
    them
  - fix quotify of very large or very small numbers
  - fix accuracy of quotify on high precision numbers when perl is compiled
    with quadmath
  - quotify will use hex floats when needed for full accuracy if they are
    available
  - change tests of quotify for floating point numbers to allow a small amount
    of inaccuracy, since decimal floats can't always be accurate
* Wed Mar 13 2019 Stephan Kulow <coolo@suse.com>
- updated to 2.006003
  see /usr/share/doc/packages/perl-Sub-Quote/Changes
  2.006003 - 2019-03-10
  - releasing as stable
  2.006_002 - 2019-01-29
  - Fix quotifying of backslashes in utf8-flagged strings on perl 5.10.0.
  2.006_001 - 2019-01-07
  - avoid warnings or failures on new perls when testing quoting UTF-8 strings
  - test quotify output under utf8 pragma
  - fix quoting of negative NaN
  2.006_000 - 2018-12-29
  - don't test threads behavior on perl < 5.8.5, since they are too unstable
  - more tests
  - preserve inf, nan, and false in quotify
  - improve accuracy of quotified floating point numbers
  - SUB_QUOTE_DEBUG can now be set to sub names, package names, or a regex to
    match against the code to filter which generated subs are printed to STDERR.
* Sat Apr 21 2018 coolo@suse.com
- updated to 2.005001
  see /usr/share/doc/packages/perl-Sub-Quote/Changes
  2.005001 - 2018-04-20
  - add a workaround for test failures on early 5.8 releases with threads
* Wed Feb  7 2018 coolo@suse.com
- updated to 2.005000
  see /usr/share/doc/packages/perl-Sub-Quote/Changes
  2.005000 - 2018-02-06
  - fixed defer_info and undefer_sub from returning data for a deferred sub
    after it expires, even if the ref address matches
  - fixed defer_info not returning info for undeferred unnamed subs after the
    deferred sub expires
  - include options in defer_info return data
  - exclude internals from defer_info return data
  - document defer_info function
  - encode all utf8 flagged scalars as strings, since they generally will
    always have originated as strings.  Avoids future warning on bitwise ops
    on strings with wide characters.
  - more thorough check for threads availability to avoid needless test
    failures.
  - added file and line options to quote_sub to allow specifying apparent
    source location.
  - documented additional options to Sub::Defer::defer_sub and
    Sub::Quote::quote_sub.
* Fri Jun  9 2017 coolo@suse.com
- updated to 2.004000
  see /usr/share/doc/packages/perl-Sub-Quote/Changes
  2.004000 - 2017-06-07
  - more extensive quotify tests
  - split tests into separate files
  - propagate package to deferred subs, even if unnamed
  - reject invalid attributes
  - include line numbers compile errors (PR#1, djerius)
* Wed Jan 11 2017 coolo@suse.com
- initial package 2.003001
  * created by cpanspec 1.78.08
